@@ -8,11 +8,13 @@
 */
 
 /* .Call calls */
-extern SEXP _psbcSpeedUp_psbcSpeedUp_internal(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern SEXP _psbcSpeedUp_drive(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
-static const R_CallMethodDef CallEntries[] = {
-    {"_psbcSpeedUp_psbcSpeedUp_internal", (DL_FUNC)&_psbcSpeedUp_psbcSpeedUp_internal, 13},
-    {NULL, NULL, 0}};
+static const R_CallMethodDef CallEntries[] =
+{
+    {"_psbcSpeedUp_drive", (DL_FUNC)&_psbcSpeedUp_drive, 14},
+    {NULL, NULL, 0}
+};
 
 void R_init_psbcSpeedUp(DllInfo *dll)
 {
